This function checks if the required Python package (kuzu) is available
in the user's reticulate environment. If the package is missing, it
provides a clear, actionable message guiding the user on how to install
it manually.
This function checks if the required Python package (kuzu) is available
in the user's reticulate environment. If the package is missing, it
provides a clear, actionable message guiding the user on how to install
it manually.