Learn R Programming

kuzuR (version 0.2.3)

check_kuzu_installation: Check for Kuzu Python Dependencies

Description

This function checks if the required Python packages (kuzu, pandas, networkx) are available in the user's reticulate environment. If any packages are missing, it provides a clear, actionable message guiding the user on how to install them manually.

Usage

check_kuzu_installation()

Arguments

Value

NULL invisibly. The function is called for its side effect of checking dependencies and printing messages.

Examples

Run this code
# \donttest{
check_kuzu_installation()
# }

Run the code above in your browser using DataLab